==> py3-bokeh-2.4.3.tgz: lib/python3.9/site-packages/bokeh/themes/_contrast.py <==
#-----------------------------------------------------------------------------
# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
# All rights reserved.
#
# The full license is in the file LICENSE.txt, distributed with this software.
#-----------------------------------------------------------------------------

json = {
    "attrs": {
        "Figure" : {
            "background_fill_color": "#000000",
            "border_fill_color": "#FFFFFF",
            "outline_line_color": "#000000",
            "outline_line_alpha": 0.25
        },

        "Grid": {
            "grid_line_color": "#E0E0E0",
            "grid_line_alpha": 0.25
        },

        "Axis": {
            "major_tick_line_alpha": 0,
            "major_tick_line_color": "#000000",

            "minor_tick_line_alpha": 0,
            "minor_tick_line_color": "#000000",

            "axis_line_alpha": 0,
            "axis_line_color": "#000000",

            "major_label_text_color": "#000000",
            "major_label_text_font": "Helvetica",
            "major_label_text_font_size": "1.025em",

            "axis_label_standoff": 10,
            "axis_label_text_color": "#000000",
            "axis_label_text_font": "Helvetica",
            "axis_label_text_font_size": "1.25em",
            "axis_label_text_font_style": "normal"
        },

        "Legend": {
            "spacing": 8,
            "glyph_width": 15,

            "label_standoff": 8,
            "label_text_color": "#FFFFFF",
            "label_text_font": "Helvetica",
            "label_text_font_size": "1.025em",

            "border_line_alpha": 0,
            "background_fill_alpha": 0.25,
            "background_fill_color": "#000000"
        },

        "ColorBar": {
            "title_text_color": "#E0E0E0",
            "title_text_font": "Helvetica",
            "title_text_font_size": "1.025em",
            "title_text_font_style": "normal",

            "major_label_text_color": "#E0E0E0",
            "major_label_text_font": "Helvetica",
            "major_label_text_font_size": "1.025em",

            "background_fill_color": "#15191C",
            "major_tick_line_alpha": 0,
            "bar_line_alpha": 0
        },

        "Title": {
            "text_color": "#000000",
            "text_font": "Helvetica",
            "text_font_size": "1.15em"
        }
    }
}

==> py3-bokeh-3.3.3.tgz: lib/python3.10/site-packages/bokeh/themes/_contrast.py <==
#-----------------------------------------------------------------------------
# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
# All rights reserved.
#
# The full license is in the file LICENSE.txt, distributed with this software.
#-----------------------------------------------------------------------------

json = {
    "attrs": {
        "Plot": {
            "background_fill_color": "#000000",
            "border_fill_color": "#FFFFFF",
            "outline_line_color": "#000000",
            "outline_line_alpha": 0.25,
        },

        "Grid": {
            "grid_line_color": "#E0E0E0",
            "grid_line_alpha": 0.25,
        },

        "Axis": {
            "major_tick_line_alpha": 0,
            "major_tick_line_color": "#000000",

            "minor_tick_line_alpha": 0,
            "minor_tick_line_color": "#000000",

            "axis_line_alpha": 0,
            "axis_line_color": "#000000",

            "major_label_text_color": "#000000",
            "major_label_text_font": "Helvetica",
            "major_label_text_font_size": "1.025em",

            "axis_label_standoff": 10,
            "axis_label_text_color": "#000000",
            "axis_label_text_font": "Helvetica",
            "axis_label_text_font_size": "1.25em",
            "axis_label_text_font_style": "normal",
        },

        "Legend": {
            "spacing": 8,
            "glyph_width": 15,

            "label_standoff": 8,
            "label_text_color": "#FFFFFF",
            "label_text_font": "Helvetica",
            "label_text_font_size": "1.025em",

            "border_line_alpha": 0,
            "background_fill_alpha": 0.25,
            "background_fill_color": "#000000",
        },

        "BaseColorBar": {
            "title_text_color": "#E0E0E0",
            "title_text_font": "Helvetica",
            "title_text_font_size": "1.025em",
            "title_text_font_style": "normal",

            "major_label_text_color": "#E0E0E0",
            "major_label_text_font": "Helvetica",
            "major_label_text_font_size": "1.025em",

            "background_fill_color": "#15191C",
            "major_tick_line_alpha": 0,
            "bar_line_alpha": 0,
        },

        "Title": {
            "text_color": "#000000",
            "text_font": "Helvetica",
            "text_font_size": "1.15em",
        },
    },
}
